@@ -56,6 +56,35 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateCluster(self, request):
+        """创建EMR集群实例
+
+        :param request: Request instance for CreateCluster.
+        :type request: :class:`tencentcloud.emr.v20190103.models.CreateClusterRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.CreateClusterResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateCluster", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateClusterResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateInstance(self, request):
         """创建EMR集群实例
 
@@ -85,8 +114,37 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteUserManagerUserList(self, request):
+        """删除用户列表（用户管理）
+
+        :param request: Request instance for DeleteUserManagerUserList.
+        :type request: :class:`tencentcloud.emr.v20190103.models.DeleteUserManagerUserListRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.DeleteUserManagerUserListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteUserManagerUserList", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteUserManagerUserListResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeClusterNodes(self, request):
-        """查询硬件节点信息
+        """查询集群节点信息
 
         :param request: Request instance for DescribeClusterNodes.
         :type request: :class:`tencentcloud.emr.v20190103.models.DescribeClusterNodesRequest`
@@ -173,7 +231,7 @@ class EmrClient(AbstractClient):
 
 
     def DescribeInstanceRenewNodes(self, request):
-        """预付费集群隔离后续费资源查询
+        """查询待续费节点信息
 
         :param request: Request instance for DescribeInstanceRenewNodes.
         :type request: :class:`tencentcloud.emr.v20190103.models.DescribeInstanceRenewNodesRequest`
@@ -202,7 +260,7 @@ class EmrClient(AbstractClient):
 
 
     def DescribeInstances(self, request):
-        """查询EMR实例
+        """查询集群实例信息
 
         :param request: Request instance for DescribeInstances.
         :type request: :class:`tencentcloud.emr.v20190103.models.DescribeInstancesRequest`
@@ -231,7 +289,7 @@ class EmrClient(AbstractClient):
 
 
     def DescribeInstancesList(self, request):
-        """EMR集群实例列表查询
+        """查询集群列表
 
         :param request: Request instance for DescribeInstancesList.
         :type request: :class:`tencentcloud.emr.v20190103.models.DescribeInstancesListRequest`
@@ -289,7 +347,7 @@ class EmrClient(AbstractClient):
 
 
     def DescribeResourceSchedule(self, request):
-        """获取yarn资源调度页面的数据
+        """查询YARN资源调度数据信息
 
         :param request: Request instance for DescribeResourceSchedule.
         :type request: :class:`tencentcloud.emr.v20190103.models.DescribeResourceScheduleRequest`
@@ -493,7 +551,7 @@ class EmrClient(AbstractClient):
 
 
     def ModifyResourcePools(self, request):
-        """刷新动态资源池
+        """刷新YARN的动态资源池
 
         :param request: Request instance for ModifyResourcePools.
         :type request: :class:`tencentcloud.emr.v20190103.models.ModifyResourcePoolsRequest`
@@ -522,7 +580,7 @@ class EmrClient(AbstractClient):
 
 
     def ModifyResourceScheduleConfig(self, request):
-        """修改yarn资源调度的资源配置
+        """修改YARN资源调度的资源配置
 
         :param request: Request instance for ModifyResourceScheduleConfig.
         :type request: :class:`tencentcloud.emr.v20190103.models.ModifyResourceScheduleConfigRequest`
@@ -608,8 +666,37 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ScaleOutCluster(self, request):
+        """扩容集群节点
+
+        :param request: Request instance for ScaleOutCluster.
+        :type request: :class:`tencentcloud.emr.v20190103.models.ScaleOutClusterRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.ScaleOutClusterResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ScaleOutCluster", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ScaleOutClusterResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ScaleOutInstance(self, request):
-        """实例扩容
+        """扩容节点
 
         :param request: Request instance for ScaleOutInstance.
         :type request: :class:`tencentcloud.emr.v20190103.models.ScaleOutInstanceRequest`
